==> nextcloud-app-news-1%3A25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/hr.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Zahtjev nije uspio, mrežna veza nije dostupna!",
    "Request unauthorized. Are you logged in?" : "Neovlašten zahtjev. Jeste li prijavljeni?",
    "Token expired or app not enabled! Reload the page!" : "Token je istekao ili aplikacija nije omogućena! Učitajte stranicu ponovo!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Unutarnja pogreška poslužitelja! Provjerite svoje podatke/datoteku nextcloud.log za dodatne informacije!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahtjev nije uspio, Nextcloud je trenutno u načinu održavanja!",
    "News feeds" : "Sažeci vijesti",
    "Unread articles" : "Nepročitani članci",
    "News" : "Vijesti",
    "News folders" : "Mape vijesti",
    "Shared with me" : "Dijeljeno sa mnom",
    "An RSS/Atom feed reader" : "RSS/Atom čitač sažetaka",
    "Download" : "Preuzmi",
    "Close" : "Zatvori",
    "Web address" : "Web adresa",
    "No folder" : "Nema mape",
    "Folder name" : "Naziv mape",
    "Username" : "Korisničko ime",
    "Password" : "Zaporka",
    "Feed exists already!" : "Sažetak već postoji!",
    "New folder" : "Nova mapa",
    "Folder exists already!" : "Mapa već postoji!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth vjerodajnice moraju biti pohranjene nešifrirane! Svi koji imaju pristup poslužitelju ili bazi podataka moći će im pristupiti!",
    "Credentials" : "Vjerodajnice",
    "Auto discover Feed" : "Automatsko otkrivanje sažetaka događaja",
    "Subscribe" : "Preplata",
    "Maximum read count per feed" : "Maksimalni broj čitanja po sažetku",
    "Maximum redirects" : "Maksimalni broj preusmjeravanja",
    "Feed fetcher timeout" : "Vremensko ograničenje hvatača sažetaka",
    "Explore Service URL" : "Istražite URL servisa",
    "Update interval" : "Interval ažuriranja",
    "Use system cron for updates" : "Koristi sustav cron za ažuriranja",
    "Disable this if you use a custom updater." : "Onemogućite ovo ako koristite prilagođenim alatom za ažuriranje.",
    "How many redirects the feed fetcher should follow." : "Koliko preusmjeravanja bi hvatač sažetaka trebao pratiti.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalni broj sekundi koliko se čeka učitavanje RSS i Atom sažetaka; ako učitavanje duže traje, nadogradnja se prekida.",
    "Interval in seconds in which the feeds will be updated." : "Interval u sekundama u kojem će se sažeci ažurirati.",
    "Move" : "Premjesti",
    "Share" : "Dijeli",
    "Mark read" : "Označi kao pročitano",
    "All articles" : "Svi članci",
    "Starred" : "Označeno zvjezdicom",
    "Explore" : "Istraži",
    "Settings" : "Postavke",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Disable mark read through scrolling" : "Onemogući označavanje kao pročitano pri pomicanju",
    "Show all articles" : "Prikaži sve članke",
    "Reverse ordering (oldest on top)" : "Obrnuti poredak (prvo najstariji)",
    "Default" : "Zadani",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Rename Feed" : "Preimenuj sažetak",
    "Unpin from top" : "Skini s vrha",
    "Pin to top" : "Prikvači na vrh",
    "Newest first" : "Najnoviji prvi",
    "Oldest first" : "Najstariji prvi",
    "Default order" : "Zadani poredak",
    "Enable full text" : "Omogući cijeli tekst",
    "Disable full text" : "Onemogući cijeli tekst",
    "Unread updated" : "Ažurirano nepročitano",
    "Ignore updated" : "Zanemari ažurirano",
    "Toggle star article" : "Postavi/ukloni zvjezdicu s članka",
    "Mark unread" : "Označi kao nepročitano",
    "Close details" : "Zatvori pojedinosti",
    "by" : "preko",
    "from" : "od",
    "shared by" : "dijeli",
    "Play audio" : "Reproduciraj zvuk",
    "Download audio" : "Preuzmi zvuk",
    "Download video" : "Preuzmi videozapis",
    "Open website" : "Otvori web-mjesto",
    "Keep article unread" : "Drži članak kao nepročitan",
    "Toggle keep current article unread" : "Prebaci i zadržati trenutni članak nepročitanim",
    "Remove keep article unread" : "Makni održavanje članaka nepročitanim",
    "Title" : "Naslov",
    "Keyboard shortcut" : "Tipkovni prečac",
    "Action" : "Radnja",
    "Jump to next article" : "Prijeđi na sljedeći članak",
    "Jump to previous article" : "Prijeđi na prethodni članak",
    "right" : "desno",
    "left" : "lijevo",
    "Star article and jump to next one" : "Označi zvjezdicom članak i prijeđi na sljedeći",
    "Open article in new tab" : "Otvori članak u novoj kartici",
    "Refresh" : "Osvježi",
    "Load next feed" : "Učitaj sljedeći sažetak",
    "Load previous feed" : "Učitaj prethodni sažetak",
    "Load previous folder" : "Učitaj prethodnu mapu",
    "Load next folder" : "Učitaj sljedeću mapu",
    "Scroll to active navigation entry" : "Pomakni se do unosa aktivne navigacije",
    "Shift" : "Pomakni",
    "Subscribe to" : "Pretplati se na",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Otkriven je Ajax ili webcron! Vaši sažeci neće biti ažurirani!",
    "How to set up the operating system cron" : "Kako postaviti cron operacijskog sustava",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalirajte i postavite brži paralelni program za ažuriranje koji se koristi API-jem za ažuriranje aplikacije Vijesti",
    "No articles available" : "Nema dostupnih članaka",
    "No unread articles available" : "Nema nepročitanih članaka",
    "Star article" : "Označi zvjezdicom članak",
    "Unstar article" : "Makni zvjezdicu s članka",
    "Share with users" : "Dijeli s korisnicima",
    "No users found" : "Nije pronađen nijedan korisnik",
    "Error while searching for users" : "Pogreška pri traženju korisnika",
    "Share on social media" : "Dijeli na društvenim mrežama",
    "I wanted you to see this article" : "Ovaj članak bi vas mogao zanimati",
    "Check out this article" : "Pogledajte ovaj članak",
    "Description" : "Opis",
    "Toggle expand article in compact view" : "Prebaci i proširi članak u kompaktnom prikazu",
    "Mark current article's feed/folder read" : "Označi sažetak/mapu trenutnog članka kao pročitan",
    "Folder" : "Mapa",
    "Go back" : "Natrag",
    "New Folder" : "Nova mapa",
    "Create" : "Stvori",
    "Update failed more than 50 times" : "Ažuriranje nije uspjelo više od 50 puta",
    "Deleted feed" : "Izbrisani sažetak",
    "Undo delete feed" : "Vrati izbrisani sažetak",
    "Menu" : "Izbornik",
    "Open feed URL" : "Otvori URL sažetka",
    "Dismiss" : "Zanemari",
    "Collapse" : "Sakrij",
    "Deleted folder" : "Izbrisana mapa",
    "Undo delete folder" : "Vrati izbrisanu mapu",
    "Compact view" : "Kompaktni prikaz",
    "Expand articles on key navigation" : "Proširi članke pri ključnoj navigaciji",
    "Subscriptions (OPML)" : "Pretplate (OPML)",
    "Import" : "Uvezi",
    "Export" : "Izvoz",
    "Error when importing: File does not contain valid OPML" : "Pogreška prilikom uvoza: datoteka ne sadrži valjani OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Pogreška pri uvozu: OPML ne sadrži sažetke ni mape",
    "Unread/Starred Articles" : "Nepročitani/članci označeni zvjezdicom",
    "Error when importing: file does not contain valid JSON" : "Pogreška pri uvozu: datoteka ne sadrži valjani JSON",
    "Help" : "Pomoć",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Prijavi pogrešku"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-app-news-1%3A27.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/hr.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Sažeci vijesti",
    "Unread articles" : "Nepročitani članci",
    "News" : "Vijesti",
    "News folders" : "Mape vijesti",
    "Shared with me" : "Dijeljeno sa mnom",
    "An RSS/Atom feed reader" : "RSS/Atom čitač sažetaka",
    "Download" : "Preuzmi",
    "Close" : "Zatvori",
    "Web address" : "Web adresa",
    "No folder" : "Nema mape",
    "Folder name" : "Naziv mape",
    "Username" : "Korisničko ime",
    "Password" : "Zaporka",
    "Feed exists already!" : "Sažetak već postoji!",
    "New folder" : "Nova mapa",
    "Folder exists already!" : "Mapa već postoji!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth vjerodajnice moraju biti pohranjene nešifrirane! Svi koji imaju pristup poslužitelju ili bazi podataka moći će im pristupiti!",
    "Credentials" : "Vjerodajnice",
    "Auto discover Feed" : "Automatsko otkrivanje sažetaka događaja",
    "Subscribe" : "Preplata",
    "Maximum read count per feed" : "Maksimalni broj čitanja po sažetku",
    "Maximum redirects" : "Maksimalni broj preusmjeravanja",
    "Feed fetcher timeout" : "Vremensko ograničenje hvatača sažetaka",
    "Explore Service URL" : "Istražite URL servisa",
    "Update interval" : "Interval ažuriranja",
    "Use system cron for updates" : "Koristi sustav cron za ažuriranja",
    "Disable this if you use a custom updater." : "Onemogućite ovo ako koristite prilagođenim alatom za ažuriranje.",
    "How many redirects the feed fetcher should follow." : "Koliko preusmjeravanja bi hvatač sažetaka trebao pratiti.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalni broj sekundi koliko se čeka učitavanje RSS i Atom sažetaka; ako učitavanje duže traje, nadogradnja se prekida.",
    "Interval in seconds in which the feeds will be updated." : "Interval u sekundama u kojem će se sažeci ažurirati.",
    "Show all articles" : "Prikaži sve članke",
    "Move" : "Premjesti",
    "Share" : "Dijeli",
    "Default" : "Zadani",
    "Mark read" : "Označi kao pročitano",
    "All articles" : "Svi članci",
    "Starred" : "Označeno zvjezdicom",
    "Explore" : "Istraži",
    "Settings" : "Postavke",
    "Documentation" : "Dokumentacija",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Disable mark read through scrolling" : "Onemogući označavanje kao pročitano pri pomicanju",
    "Reverse ordering (oldest on top)" : "Obrnuti poredak (prvo najstariji)",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Rename Feed" : "Preimenuj sažetak",
    "Unpin from top" : "Skini s vrha",
    "Pin to top" : "Prikvači na vrh",
    "Newest first" : "Najnoviji prvi",
    "Oldest first" : "Najstariji prvi",
    "Default order" : "Zadani poredak",
    "Enable full text" : "Omogući cijeli tekst",
    "Disable full text" : "Onemogući cijeli tekst",
    "Toggle star article" : "Postavi/ukloni zvjezdicu s članka",
    "Mark unread" : "Označi kao nepročitano",
    "Close details" : "Zatvori pojedinosti",
    "shared by" : "dijeli",
    "by" : "preko",
    "Play audio" : "Reproduciraj zvuk",
    "Download audio" : "Preuzmi zvuk",
    "Download video" : "Preuzmi videozapis",
    "Open website" : "Otvori web-mjesto",
    "Keep article unread" : "Drži članak kao nepročitan",
    "Toggle keep current article unread" : "Prebaci i zadržati trenutni članak nepročitanim",
    "Remove keep article unread" : "Makni održavanje članaka nepročitanim",
    "Please wait" : "Pričekajte",
    "Title" : "Naslov",
    "Folder" : "Mapa",
    "Keyboard shortcut" : "Tipkovni prečac",
    "Action" : "Radnja",
    "Jump to next article" : "Prijeđi na sljedeći članak",
    "Jump to previous article" : "Prijeđi na prethodni članak",
    "right" : "desno",
    "left" : "lijevo",
    "Star article and jump to next one" : "Označi zvjezdicom članak i prijeđi na sljedeći",
    "Open article in new tab" : "Otvori članak u novoj kartici",
    "Refresh" : "Osvježi",
    "Load next feed" : "Učitaj sljedeći sažetak",
    "Load previous feed" : "Učitaj prethodni sažetak",
    "Load previous folder" : "Učitaj prethodnu mapu",
    "Load next folder" : "Učitaj sljedeću mapu",
    "Scroll to active navigation entry" : "Pomakni se do unosa aktivne navigacije",
    "Shift" : "Pomakni",
    "Subscribe to" : "Pretplati se na",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Otkriven je Ajax ili webcron! Vaši sažeci neće biti ažurirani!",
    "How to set up the operating system cron" : "Kako postaviti cron operacijskog sustava",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalirajte i postavite brži paralelni program za ažuriranje koji se koristi API-jem za ažuriranje aplikacije Vijesti"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
